@@ -8,9 +8,10 @@ OC.L10N.register(
     "Send email" : "Saada kiri",
     "Download" : "Lae alla",
     "Rename" : "Nimeta ümber",
-    "Enabled" : "Lubatud",
     "Delete" : "Kustuta",
     "Copy link" : "Kopeeri link",
+    "_%n contact_::_%n contacts_" : ["%n kontakt","%nkontakti"],
+    "_%n group_::_%n groups_" : ["%n grupp","%n gruppi"],
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
     "No users or groups" : "Ei ole kasutajaid või gruppe",
     "can edit" : "saab redigeerida",
@@ -32,7 +33,6 @@ OC.L10N.register(
     "No results" : "Vasteid ei leitud",
     "Personal circle" : "Isiklik ring",
     "Pending" : "Ootel",
-    "None" : "Pole",
     "Close" : "Sulge",
     "Import" : "Impordi",
     "Not grouped" : "Pole grupeeritud",
@@ -94,6 +94,7 @@ OC.L10N.register(
     "Gender" : "Sugu",
     "Female" : "Naine",
     "Male" : "Mees",
+    "None" : "Pole",
     "Unknown" : "Teadmata"
 },
 "nplurals=2; plural=(n != 1);");
