@@ -10,12 +10,11 @@ OC.L10N.register(
     "Loading contacts …" : "Duke ngarkuar kontaktet ...",
     "Delete circle" : "Fshini rrethin",
     "General settings" : "Opsjonet e Pergjithshme",
-    "Download" : "Shkarko",
     "Send email" : "Dërgo email",
     "Circles" : "Rrethet",
     "Create a new circle" : "Krijo një rreth të ri",
+    "Download" : "Shkarko",
     "Rename" : "Riemëro",
-    "Enabled" : "I aktivizuar",
     "Delete" : "Fshije",
     "Copied" : "Kopjuar",
     "Copy link" : "Kopjo linkun",
@@ -28,13 +27,11 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Ruaj",
     "Description" : "Përshkrim",
-    "Add new property" : "Shto karakteristikë të re",
-    "Choose property type" : "Zgjidh llojin e  karakteristikës",
+    "Cancel" : "Anullo",
     "Upload a new picture" : "Ngarko një foto të re",
     "Download picture" : "Shkarko foton",
     "Delete picture" : "Fshi foton",
     "Invalid image" : "Figurë e pavlefshme",
-    "Image is too big (max 1MB)." : "Imazhi është shumë i madh (maksimumi 1MB).",
     "Pick an avatar" : "Zgjidh një avatar",
     "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
     "Avatar already up to date" : "Avatari është i përditësuar.",
@@ -42,12 +39,10 @@ OC.L10N.register(
     "No contact selected" : "Nuk është zgjedhur asnjë kontakt",
     "Select a contact on the list to begin" : "Zgjidh një kontakt nga lista për të filluar",
     "Name" : "Emri",
-    "Company" : "Kompania",
     "Title" : "Titulli",
+    "Company" : "Kompania",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "Ky kontakt ishte prishur dhe u rregullua. Ju lutem rishikoni përmbajtjen dhe klikoni këtu për ta ruajtur atë.",
     "Generate QR Code" : "Gjeneroni Kodin QR",
-    "Cancel" : "Anullo",
-    "This contact is not yet synced. Edit it to save it to the server." : "Ky kontakt nuk është sinkronizuar akoma. Përditësojeni atë për ta ruajtur në server.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
     "Address book" : "Libri i adresave",
@@ -73,11 +68,11 @@ OC.L10N.register(
     "Admin" : "Administrator",
     "Owner" : "Zotëruesi",
     "Users" : "Përdoruesit",
-    "Nickname" : "Nofkë",
     "Detailed name" : "Emri i hollësishëm",
     "Additional names" : "Emra shtesë",
     "Prefix" : "Parashtesë",
     "Suffix" : "Prapashtesë",
+    "Nickname" : "Nofkë",
     "Notes" : "Shënime",
     "Website" : "Faqe interneti",
     "Location" : "Vendndodhje",
