@@ -44,9 +44,10 @@ OC.L10N.register(
     "This group already exists" : "該群組已存在",
     "This circle already exists" : "此社交圈子已存在",
     "An error happened during the creation of the circle" : "創建社交圈子的過程中發生錯誤",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下載",
+    "Show" : "顯示",
     "Rename" : "重新命名",
-    "Enabled" : "已啟用",
     "Delete" : "刪除",
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
@@ -56,8 +57,11 @@ OC.L10N.register(
     "Delete {addressbook}?" : "刪除 {addressbook}？",
     "Deletion of address book was not successful." : "刪除通訊錄失敗。",
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
+    "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
+    "_%n group_::_%n groups_" : ["%n 個群組"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
     "Share with users or groups" : "與用戶或群組分享",
+    "Share with users" : "與用戶分享",
     "No users or groups" : "沒有用戶或群組",
     "can edit" : "允許編輯",
     "Unable to delete the share" : "無法刪除這個分享",
@@ -65,7 +69,7 @@ OC.L10N.register(
     "Import contacts" : "導入聯絡人",
     "Import into the {addressbookName} address book" : "導入至 {addressbookName} 通訊錄",
     "Select local file" : "選擇本機檔案",
-    "Import from Files" : "從檔案導入",
+    "Import from files" : "從檔案導入",
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
     "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
     "Add new address book" : "添加新通訊錄",
@@ -124,6 +128,8 @@ OC.L10N.register(
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
     "Pick an address book" : "選取一個通訊錄",
     "Select address book" : "選擇通訊錄",
+    "Go to talk conversation" : "前往對話",
+    "View profile" : "檢視個人檔案",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
@@ -136,6 +142,7 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
     "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
     "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
+    "Unable to update contact" : "無法更新聯絡人",
     "Search contacts …" : "搜尋聯絡人…",
     "Add to {group}" : "新增至 {group]",
     "Remove {type}" : "移除 {type}",
@@ -175,8 +182,8 @@ OC.L10N.register(
     "Select chart …" : "選擇圖表 ...",
     "Select type" : "選擇類型",
     "Select Date" : "選擇日期",
-    "None" : "無",
     "Add contact in group" : "新增聯絡人到群組",
+    "none" : "無",
     "Select option" : "選擇選項",
     "Add property of this type" : "添加此類型的屬性",
     "Unable to create the contact." : "無法建立聯絡人",
@@ -203,7 +210,7 @@ OC.L10N.register(
     "Not grouped" : "未歸類",
     "Recently contacted" : "最近聯絡",
     "Organization chart" : "機構圖表",
-    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "社交圈子允許您在 Nextcloud 實例上與其他用戶創建群組並與他們分享。",
+    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "小圈圈是您可以自行建立並與他們分享資料的一群人。其可以由 Nextcloud 站台的其他帳號或帳號群組所組成，但也可以由您通訊錄中的聯絡人組成，甚至可以透過輸入電子郵件地址來組成外部人員。",
     "Circle" : "社交圈子",
     "User" : "用戶",
     "Group" : "群組",
@@ -279,6 +286,7 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
+    "None" : "無",
     "Unknown" : "不詳",
     "Time zone" : "時區",
     "Spoken languages" : "會說的語言",
